@@ -1,15 +1,15 @@
 package App::CPANModulesUtils;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-19'; # DATE
-our $DIST = 'App-CPANModulesUtils'; # DIST
-our $VERSION = '0.006'; # VERSION
-
 use 5.010001;
 use strict 'subs', 'vars';
 use warnings;
 use Log::ger;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-11-26'; # DATE
+our $DIST = 'App-CPANModulesUtils'; # DIST
+our $VERSION = '0.007'; # VERSION
+
 our %SPEC;
 
 $SPEC{gen_acme_cpanmodules_module_from_acme_cpanlists_list} = {
@@ -116,7 +116,11 @@ sub gen_acme_cpanmodules_module_from_acme_cpanlists_list {
         "package $output_module;\n",
         "\n",
 
+        "use strict;\n\n",
+
+        "# AUTHORITY\n",
         "# DATE\n",
+        "# DIST\n",
         "# VERSION\n",
         "\n",
 
@@ -173,6 +177,10 @@ _
             schema => 'true*',
             cmdline_aliases => {O=>{}},
         },
+        description => {
+            summary => 'Add description to the list',
+            schema => 'str*',
+        },
     },
 };
 sub gen_acme_cpanmodules_module_from_webpage {
@@ -208,6 +216,8 @@ sub gen_acme_cpanmodules_module_from_webpage {
         entries => [],
     };
 
+    $list->{description} = $args{description} if $args{description};
+
     my $res = HTTP::Tiny->new->get($url);
     return [500, "Couldn't retrieve URL $url: $res->{status} - $res->{reason}"] unless $res->{success};
 
@@ -238,6 +248,8 @@ sub gen_acme_cpanmodules_module_from_webpage {
         "package $output_module;\n",
         "\n",
 
+        "use strict;\n\n",
+
         "# AUTHORITY\n",
         "# DATE\n",
         "# DIST\n",
@@ -319,7 +331,7 @@ App::CPANModulesUtils - Command-line utilities related to Acme::CPANModules
 
 =head1 VERSION
 
-This document describes version 0.006 of App::CPANModulesUtils (from Perl distribution App-CPANModulesUtils), released on 2021-05-19.
+This document describes version 0.007 of App::CPANModulesUtils (from Perl distribution App-CPANModulesUtils), released on 2021-11-26.
 
 =head1 SYNOPSIS
 
@@ -347,7 +359,7 @@ L<Acme::CPANModules>:
 
 Usage:
 
- acme_cpanmodules_for(%args) -> [status, msg, payload, meta]
+ acme_cpanmodules_for(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 List Acme::CPANModules distributions that mention specified modules.
 
@@ -372,12 +384,12 @@ Arguments ('*' denotes required arguments):
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -387,7 +399,7 @@ Return value:  (any)
 
 Usage:
 
- gen_acme_cpanmodules_module_from_acme_cpanlists_list(%args) -> [status, msg, payload, meta]
+ gen_acme_cpanmodules_module_from_acme_cpanlists_list(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Generate an Acme::CPANModules module file from an Acme::CPANLists module list.
 
@@ -423,12 +435,12 @@ CPANModules.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -438,7 +450,7 @@ Return value:  (any)
 
 Usage:
 
- gen_acme_cpanmodules_module_from_webpage(%args) -> [status, msg, payload, meta]
+ gen_acme_cpanmodules_module_from_webpage(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Generate an Acme::CPANModules module file a webpage.
 
@@ -452,6 +464,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<description> => I<str>
+
+Add description to the list.
+
 =item * B<output_file> => I<filename>
 
 will default to "lib/Acme/CPANModules/<YourModuleName>.pm
@@ -469,12 +485,12 @@ will default to "lib/Acme/CPANModules/<YourModuleName>.pm
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -486,14 +502,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-CPANMo
 
 Source repository is at L<https://github.com/perlancar/perl-App-CPANModulesUtils>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-CPANModulesUtils/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Acme::CPANModules>
@@ -502,11 +510,36 @@ L<Acme::CPANModules>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-CPANModulesUtils>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
